@@ -587,7 +587,7 @@ class Client(object):
             endpoint="service_account_authorizations", data=params)
         None
 
-    def real_time_scheduling(self, availability, oauth, event, target_calendars=(), minimum_notice=None):
+    def real_time_scheduling(self, availability, oauth, event, target_calendars=(), minimum_notice=None, callback_url=None, redirect_urls=None):
         """Generates an real time scheduling link to start the OAuth process with
         an event to be automatically upserted
 
@@ -610,6 +610,11 @@ class Client(object):
         :param list target_calendars: - An list of dics stating into which calendars
                                         to insert the created event
         :param dict :minimum_notice - A dict describing the minimum notice for a booking (Optional)
+        :param string :callback_url - A String representing the URL Cronofy will notify
+                                      once a slot has been selected.
+        :param dict redirect_urls: - A dict containing redirect URLs for the end-user's journey
+            :completed_url         - A String representing the URL the end-user
+                                     will be redirected to after choosing a slot
 
         See https://docs.cronofy.com/developers/api/scheduling/real-time-scheduling/ for reference.
         """
@@ -632,6 +637,12 @@ class Client(object):
         if minimum_notice:
             args['minimum_notice'] = self.map_availability_duration(minimum_notice)
 
+        if callback_url:
+            args['callback_url'] = callback_url
+
+        if redirect_urls:
+            args['redirect_urls'] = redirect_urls
+
         return self.request_handler.post(endpoint='real_time_scheduling', data=args, use_api_key=True).json()
 
     def real_time_sequencing(self, availability, oauth, event, target_calendars=(), minimum_notice=None):
@@ -855,3 +866,34 @@ class Client(object):
                         if calendar_item['calendar_name'] == calendar_name:
                             calendar_data = calendar_item.copy()
                 return calendar_data
+
+    def upsert_availability_rule(self, availability_rule):
+        """Inserts or updates an Availability Rule for the active account.
+
+        :param dict availability_rule: Dictionary representing the Availability Rule.
+        """
+        return self.request_handler.post(
+            endpoint='availability_rules', data=availability_rule).json()['availability_rule']
+
+    def list_availability_rules(self):
+        """Return a list of Availability Rules saved against the active account.
+
+        :return: List of Availability Rules (dictionaries).
+        :rtype: ``list``
+        """
+        return self.request_handler.get(endpoint='availability_rules').json()['availability_rules']
+
+    def get_availability_rule(self, availability_rule_id):
+        """Retrieve a single Availability Rule saved against the active account.
+
+        :return: The Availability Rule (dictionary).
+        :rtype: ``dict``
+        """
+        return self.request_handler.get(endpoint='availability_rules/%s' % availability_rule_id).json()['availability_rule']
+
+    def delete_availability_rule(self, availability_rule_id):
+        """Delete an event from the specified calendar.
+
+        :param string availability_rule_id: ID of the Availability Rule to delete.
+        """
+        self.request_handler.delete(endpoint='availability_rules/%s' % availability_rule_id)
